# Patcherex 2

[![Latest Release](https://img.shields.io/pypi/v/patcherex2.svg)](https://pypi.python.org/pypi/patcherex2/)
[![PyPI Statistics](https://img.shields.io/pypi/dm/patcherex2.svg)](https://pypistats.org/packages/patcherex2)
[![Python Version](https://img.shields.io/pypi/pyversions/patcherex2)](https://pypi.python.org/pypi/patcherex2/)
[![Test](https://img.shields.io/github/actions/workflow/status/purseclab/patcherex2/test.yml?label=test
)](https://github.com/purseclab/Patcherex2/actions/workflows/test.yml)
[![License](https://img.shields.io/github/license/purseclab/patcherex2.svg)](https://github.com/purseclab/Patcherex2/blob/main/LICENSE)


Patcherex 2 is a rewritten adaptation of the original [Patcherex](https://github.com/angr/patcherex) project, aimed at building upon its core ideas and extending its capabilities.

## Installation

Patcherex 2 is available on PyPI and can be installed with pip:

```bash
pip install patcherex2
```

## Usage

Coming soon.
